@@ -86,12 +86,13 @@ class DingTalkBot:
             self.wait()
 
         timestamp = str(round(time.time() * 1000))
-        sign = self.get_signature(timestamp, self.secret)
         params = {
             'access_token': self.access_token,
             'timestamp': timestamp,
-            'sign': sign
         }
+        if self.secret:
+            sign = self.get_signature(timestamp, self.secret)
+            params['sign'] = sign
         url = f'{self.url}?{urlencode(params)}'
         resp = requests.post(url, json=data, timeout=(10, 20))
         if self.check_response(resp):
@@ -129,7 +130,7 @@ class DingTalkBot:
 
         return self.send(text_meta, tag, interval)
 
-    async def async_send_link(self, title, desc, message_url, pic_url=None, phone=None, tag=None, interval=None):
+    async def async_send_link(self, title, desc, message_url, pic_url=None, tag=None, interval=None):
         link_meta = {
             "msgtype": "link",
             "link": {
@@ -139,18 +140,9 @@ class DingTalkBot:
                 "messageUrl": message_url
             }
         }
-
-        if phone:
-            at = {
-                "atMobiles": [
-                    phone
-                ]
-            }
-            link_meta['at'] = at
-
         return await self.async_send(link_meta, tag, interval)
 
-    def send_link(self, title, desc, message_url, pic_url=None, phone=None, tag=None, interval=None):
+    def send_link(self, title, desc, message_url, pic_url=None, tag=None, interval=None):
         link_meta = {
             "msgtype": "link",
             "link": {
@@ -160,15 +152,6 @@ class DingTalkBot:
                 "messageUrl": message_url
             }
         }
-
-        if phone:
-            at = {
-                "atMobiles": [
-                    phone
-                ]
-            }
-            link_meta['at'] = at
-
         return self.send(link_meta, tag, interval)
 
     @staticmethod
